<?php

namespace Drupal\coorrency\Form;

use Drupal\Core\Entity\EntityConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\block\Entity\Block;

/**
 * Builds the form to delete Currency exchange entities.
 */
class CurrencyExchangeDeleteForm extends EntityConfirmFormBase {

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    // @TODO Show this message only for delete page.
    // $this->messenger()->addWarning($this->t('The currency exchange block associated with this entity will also be removed.'));
    return $this->t('Are you sure you want to delete %name?', ['%name' => $this->entity->label()]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('entity.currency_exchange.collection');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Delete');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Delete block associated.
    $block = Block::load($this->entity->id());
    if ($block) {
      $block->delete();
    }
    // Delete current CurrencyExchange entity.
    $this->entity->delete();

    $this->messenger()->addMessage($this->t('The entity "@label" was removed.', [
        '@label' => $this->entity->label(),
      ])
    );
    $this->messenger()->addMessage($this->t('Block associated was removed.'));

    $form_state->setRedirectUrl($this->getCancelUrl());
  }

}
