<?php

namespace Drupal\coorrency\Form;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\coorrency\Form\CoorrencyBlockForm;

/**
 * Class CurrencyExchangeForm.
 */
class CurrencyExchangeForm extends EntityForm {

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);

    $currency_exchange = $this->entity;

    $title_editable = is_null($currency_exchange->id());
    $edit_title = '';
    if (!$title_editable) {
      $edit_title = $this->t('<strong>Edit the title through the associated block.</strong>');
    }

    $form['label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Title'),
      '#maxlength' => 255,
      '#default_value' => $currency_exchange->label(),
      '#description' => $this->t('For example, American dollar (USD). ' . $edit_title),
      '#required' => TRUE,
      '#disabled' => !$title_editable,
    ];

    $form['id'] = [
      '#type' => 'machine_name',
      '#default_value' => $currency_exchange->id(),
      '#machine_name' => [
        'exists' => '\Drupal\coorrency\Entity\CurrencyExchange::load',
      ],
      '#disabled' => !$currency_exchange->isNew(),
    ];

    $form['cant'] = [
      '#type' => 'number',
      '#title' => $this->t('Convert'),
      '#size' => 100,
      '#maxlength' => 50,
      '#min' => 1,
      '#max' => 100,
      '#required' => TRUE,
      '#default_value' => $currency_exchange->getCant(),
    ];

    $form['currency_from'] = [
      '#type' => 'select',
      '#title' => $this->t('From'),
      '#options' => CoorrencyBlockForm::getCurrencies(),
      '#required' => TRUE,
      '#default_value' => $currency_exchange->getCurrencyFrom(),
    ];

    $form['currency_to'] = [
      '#type' => 'select',
      '#title' => $this->t('To'),
      '#options' => CoorrencyBlockForm::getCurrencies(),
      '#multiple' => TRUE,
      '#required' => TRUE,
      '#size' => 10,
      '#default_value' => $currency_exchange->getCurrencyTo(),
      '#description' => $this->t('The conversion to the selected currencies is displayed.'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function actions(array $form, FormStateInterface $form_state) {
    $actions = parent::actions($form, $form_state);

    $entity_new = is_null($this->entity->id());

    $text = 'Create';
    if (!$entity_new) {
      $text = 'Update';
    }

    $actions['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t("$text Currency exchange"),
      '#submit' => ['::submitForm', '::save'],
    ];
    return $actions;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $currency_to = $form_state->getValue('currency_to');
    if (count($currency_to) > 6) {
      $form_state->setErrorByName('currency_to', $this->t('Select a maximum of 6 currencies to show the conversion'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $currency_exchange = $this->entity;
    $status = $currency_exchange->save();

    switch ($status) {
      case SAVED_NEW:
        $this->messenger()->addMessage($this->t('Created the %label Currency exchange.', [
          '%label' => $currency_exchange->label(),
        ]));
        break;

      default:
        $this->messenger()->addMessage($this->t('Saved the %label Currency exchange.', [
          '%label' => $currency_exchange->label(),
        ]));
    }
    $form_state->setRedirectUrl($currency_exchange->toUrl('collection'));
  }

}
