<?php

namespace Drupal\coorrency\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Cache\Cache;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Menu\MenuActiveTrailInterface;
use Drupal\Core\Menu\MenuLinkTreeInterface;
use Drupal\Core\Menu\MenuTreeParameters;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a generic Coorrency block list.
 *
 * @Block(
 *   id = "coorrency_block_list",
 *   admin_label = @Translation("Coorrency block list"),
 *   category = @Translation("Coorrency blocks list"),
 *   deriver = "Drupal\coorrency\Plugin\Derivative\CoorrencyBlockList",
 * )
 */
class CoorrencyBlockList extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The menu link tree service.
   *
   * @var \Drupal\Core\Menu\MenuLinkTreeInterface
   */
  protected $menuTree;

  /**
   * The active menu trail service.
   *
   * @var \Drupal\Core\Menu\MenuActiveTrailInterface
   */
  protected $menuActiveTrail;

  /**
   * Constructs a new SystemMenuBlock.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param array $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Menu\MenuLinkTreeInterface $menu_tree
   *   The menu tree service.
   * @param \Drupal\Core\Menu\MenuActiveTrailInterface $menu_active_trail
   *   The active menu trail service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, MenuLinkTreeInterface $menu_tree, MenuActiveTrailInterface $menu_active_trail = NULL) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->menuTree = $menu_tree;
    $this->menuActiveTrail = $menu_active_trail;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('menu.link_tree'),
      $container->get('menu.active_trail')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {

    $config_id = $this->getDerivativeId();
    $entity_config = \Drupal::entityTypeManager()->getStorage('currency_exchange')->load($config_id);

    $cant = $entity_config->getCant();
    $from_currency = $entity_config->getCurrencyFrom();
    $to_coins = $entity_config->getCurrencyTo();

    $get_changes = [];
    foreach ($to_coins as $to_currency) {
      $result = $this->convertCurrency($cant, $from_currency, $to_currency);
      $get_changes[] = "$cant $from_currency = $result $to_currency";
    }

    $build['theme_currency'] = [
      '#theme' => 'item_list',
      '#items' => $get_changes,
    ];

    return $build;
  }

  function convertCurrency($amount, $from_currency, $to_currency) {
    // Get api key.
    $config = \Drupal::config('coorrency.settings');
    $api_key_version = $config->get('coorrency.api_key_version');
    $api_key = $config->get('coorrency.api_key');

    // Set free and paid url.
    $url = 'https://free.currconv.com/api/v7/convert';
    if ($api_key_version) {
      $url = 'https://api.currconv.com/api/v7/convert';
    }

    $from_Currency = urlencode($from_currency);
    $to_Currency = urlencode($to_currency);
    $query =  $from_Currency . '_' . $to_Currency;

    // Get the content.
    $json = @file_get_contents("$url?q=$query&compact=ultra&apiKey=$api_key");
    if (!$json) {
      return 'UNDEFINED';
    }
    $obj = json_decode($json, TRUE);
    $val = floatval($obj[$query]);
    $total = $val * $amount;
    return number_format($total, 2, '.', '');
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    // Don't cache this block because it's necessary to have the most recent
    // update of the exchange rate.
    return 0;
  }

}
